@@ -1,31 +1,20 @@
-import asyncio
+import asyncio, hashlib, json, os, multiprocessing, copy, sys, time, atexit, pkgutil
+import bsdiff4 # pyright: ignore[reportMissingTypeStubs]
+from typing import TYPE_CHECKING, Any, List, TypedDict, cast
+from collections import Counter
 from dataclasses import dataclass
-import hashlib
-import io
-import json
-import logging
-import os
-import multiprocessing
-import copy
-import pathlib
-import subprocess
-import sys
-import time
-from typing import List, Tuple, Union
-import zipfile
-import bsdiff4
-import atexit
-import urllib.parse
 
 
 # CommonClient import first to trigger ModuleUpdater
 from CommonClient import CommonContext, server_loop, gui_enabled, \
     ClientCommandProcessor, logger, get_base_parser
 import Utils
-import settings
 from Utils import async_start, instance_name
-
 apname = instance_name if instance_name else "Archipelago"
+from . import BanjoTooieWorld
+
+if TYPE_CHECKING:
+    from kvui import UILog
 
 SYSTEM_MESSAGE_ID = 0
 
@@ -36,69 +25,57 @@ CONNECTION_TENTATIVE_STATUS = "Initial Connection Made"
 CONNECTION_CONNECTED_STATUS = "Connected"
 CONNECTION_INITIAL_STATUS = "Connection has not been initiated"
 
-"""
-Payload: lua -> client
-{
-    playerName: string,
-    locations: dict,
-    deathlinkActive: bool,
-    taglinkActive: bool,
-    isDead: bool,
-    isTag: bool,
-    gameComplete: bool
-}
-
-Payload: client -> lua
-{
-    items: list,
-    playerNames: list,
-    triggerDeath: bool,
-    triggerTag: bool,
-    messages: string
-}
-
-Deathlink logic:
-"Dead" is true <-> Banjo is at 0 hp.
-
-deathlink_pending: we need to kill the player
-deathlink_sent_this_death: we interacted with the multiworld on this death, waiting to reset with living link
-
-"""
+# Payload: lua -> client
+# {
+#     playerName: string,
+#     locations: dict,
+#     deathlinkActive: bool,
+#     taglinkActive: bool,
+#     isDead: bool,
+#     isTag: bool,
+#     gameComplete: bool
+# }
+#
+# Payload: client -> lua
+# {
+#     items: list,
+#     playerNames: list,
+#     triggerDeath: bool,
+#     triggerTag: bool,
+#     messages: string
+# }
+#
+# Deathlink logic:
+# "Dead" is true <-> Banjo is at 0 hp.
+#
+# deathlink_pending: we need to kill the player
+# deathlink_sent_this_death: we interacted with the multiworld on this death, waiting to reset with living link
 
 bt_loc_name_to_id = {}
 bt_itm_name_to_id = {}
 script_version: int = 5
-version: str = "V4.11.3"
-patch_md5: str = "54efb965e58f1bb15487d411dc8955a3"
-bt_options = settings.get_settings().banjo_tooie_options
+version: str = BanjoTooieWorld.world_version.as_simple_string()
+patch_md5: str = "301fb828cb16db9001414954693f3a49"
+bt_options = BanjoTooieWorld.settings
 program = None
 
-def read_file(path):
+def read_file(path: str) -> bytes:
   with open(path, "rb") as fi:
     data = fi.read()
   return data
 
-def write_file(path, data):
+def write_file(path: str, data: bytes):
   with open(path, "wb") as fi:
     fi.write(data)
 
-def open_world_file(resource: str, mode: str = "rb", encoding: str = None):
-  filename = sys.modules[__name__].__file__
-  apworldExt = ".apworld"
-  game = "banjo_tooie/"
-  if apworldExt in filename:
-    zip_path = pathlib.Path(filename[:filename.index(apworldExt) + len(apworldExt)])
-    with zipfile.ZipFile(zip_path) as zf:
-      zipFilePath = game + resource
-      if mode == "rb":
-        return zf.open(zipFilePath, "r")
-      else:
-        return io.TextIOWrapper(zf.open(zipFilePath, "r"), encoding)
-  else:
-    return open(os.path.join(pathlib.Path(__file__).parent, resource), mode, encoding=encoding)
+def open_world_file(resource: str) -> bytes:
+  assert __package__ is not None, "BTClient needs to be loaded as a package."
+  ret = pkgutil.get_data(__package__, resource)
+  assert ret is not None, f"Unable to find: {resource}"
+  return ret
 
-def patch_rom(rom_path, dst_path, patch_path):
-  rom = read_file(rom_path)
+def patch_rom(rom_path: str, dst_path: str, patch_path: str):
+  rom: bytes = read_file(rom_path)
   md5 = hashlib.md5(rom).hexdigest()
   if md5 == "ca0df738ae6a16bfb4b46d3860c159d9": # byte swapped
     swapped = bytearray(b'\0'*len(rom))
@@ -109,12 +86,12 @@ def patch_rom(rom_path, dst_path, patch_path):
   elif md5 != "40e98faa24ac3ebe1d25cb5e5ddf49e4":
     logger.error(f"Unknown ROM! Please use /patch or restart the {apname} Client to try again.")
     return False
-  with open_world_file(patch_path) as f:
-    patch = f.read()
-  write_file(dst_path, bsdiff4.patch(rom, patch))
+  patch = open_world_file(patch_path)
+  patched_rom = cast(bytes, bsdiff4.patch(rom, patch)) # pyright: ignore[reportUnknownMemberType]
+  write_file(dst_path, patched_rom)
   return True
 
-async def patch_and_run(show_path):
+async def patch_and_run(show_path: bool):
   global program
   game_name = "Banjo-Tooie"
   patch_path = bt_options.get("patch_path", "")
@@ -170,8 +147,7 @@ async def patch_and_run(show_path):
           program_args = f'--lua={lua}'
           if os.access(os.path.split(lua)[0], os.W_OK):
             with open(lua, "w") as to:
-              with open_world_file("assets/connector_banjo_tooie_bizhawk.lua") as f:
-                to.write(f.read().decode())
+              to.write(open_world_file("assets/connector_banjo_tooie_bizhawk.lua").decode())
         args.append(program_args)
       args.append(patch_path)
       program = subprocess.Popen(
@@ -182,29 +158,28 @@ async def patch_and_run(show_path):
         stderr=subprocess.DEVNULL,
       )
 
-def get_item_value(ap_id):
-    return ap_id
+class BanjoTooieClientTab:
+    content: "UILog"
 
 class BanjoTooieItemTracker:
 
-  def __init__(self, ctx):
+  def __init__(self, ctx: "BanjoTooieContext"):
     self.ctx = ctx
-    self.items = {item_name: 0 for item_name in bt_itm_name_to_id}
+    self.items: Counter[str] = Counter()
     self.refresh_items()
 
   def refresh_items(self):
-    for item in self.items:
-      self.items[item] = 0
+    self.items.clear()
     for item in self.ctx.items_received:
       self.items[self.ctx.item_names.lookup_in_game(item.item)] += 1
-    self.ctx.tab_items.content.data = []
+    data: list[dict[str, str]] = []
     for item_name, amount in sorted(self.items.items()):
-      if amount == 0: continue
-      if amount > 1: self.ctx.tab_items.content.data.append({"text":f"{item_name}: {amount}"})
-      else: self.ctx.tab_items.content.data.append({"text":f"{item_name}"})
+      if amount > 1: data.append({"text":f"{item_name}: {amount}"})
+      else: data.append({"text":f"{item_name}"})
+    self.ctx.tab_items.content.data = data
 
 class BanjoTooieCommandProcessor(ClientCommandProcessor):
-    def __init__(self, ctx):
+    def __init__(self, ctx: "BanjoTooieContext"):
         super().__init__(ctx)
 
     def _cmd_patch(self):
@@ -234,7 +209,7 @@ class BanjoTooieCommandProcessor(ClientCommandProcessor):
             logger.info("Autostart disabled.")
         return True
 
-    def _cmd_rom_path(self, path=""):
+    def _cmd_rom_path(self, path: str = ""):
         """Sets (or unsets) the file path of the vanilla ROM used for patching."""
         bt_options.rom_path = path
         bt_options._changed = True
@@ -244,7 +219,7 @@ class BanjoTooieCommandProcessor(ClientCommandProcessor):
             logger.info("rom_path unset!")
         return True
 
-    def _cmd_patch_path(self, path=""):
+    def _cmd_patch_path(self, path: str = ""):
         """Sets (or unsets) the folder path of where to save the patched ROM."""
         bt_options.patch_path = path
         bt_options._changed = True
@@ -254,7 +229,7 @@ class BanjoTooieCommandProcessor(ClientCommandProcessor):
             logger.info("patch_path unset!")
         return True
 
-    def _cmd_program_args(self, path=""):
+    def _cmd_program_args(self, path: str = ""):
         """Sets (or unsets) the arguments to pass to the automatically run program. Defaults to passing the lua to Bizhawk."""
         bt_options.program_args = path
         bt_options._changed = True
@@ -288,10 +263,15 @@ class BanjoTooieCommandProcessor(ClientCommandProcessor):
     #     if isinstance(self.ctx, BanjoTooieContext):
     #         async_start(self.ctx.send_tag_link(), name="Send Taglink")
 
+@dataclass
+class CreateHintsParams:
+    location: int
+    player: int
 
 class BanjoTooieContext(CommonContext):
     command_processor = BanjoTooieCommandProcessor
     items_handling = 0b111 #full
+    tab_items: BanjoTooieClientTab
 
     def __init__(self, server_address, password, ready_callback=None, error_callback=None):
         super().__init__(server_address, password)
@@ -299,43 +279,43 @@ class BanjoTooieContext(CommonContext):
         self.ready_callback = ready_callback
         self.error_callback = error_callback
         self.game = "Banjo-Tooie"
-        self.n64_streams: (StreamReader, StreamWriter) = None # type: ignore
+        self.n64_streams: tuple[asyncio.StreamReader, asyncio.StreamWriter] | None = None
         self.n64_sync_task = None
         self.n64_status = CONNECTION_INITIAL_STATUS
         self.awaiting_rom = False
         self.location_table = {}
-        self.movelist_table = {}
-        self.cheatorewardslist_table = {}
-        self.honeybrewardslist_table = {}
-        self.treblelist_table = {}
-        self.stationlist_table = {}
-        self.jinjofamlist_table = {}
-        self.jinjolist_table = {}
-        self.pages_table = {}
-        self.honeycomb_table = {}
-        self.glowbo_table = {}
-        self.doubloon_table = {}
-        self.notes_table = {}
-        self.worldlist_table = {}
-        self.chuffy_table = {}
-        self.mystery_table = {}
-        self.roystenlist_table = {}
-        self.jiggychunks_table = {}
+        self.movelist_table: dict[str, bool] = {}
+        self.cheatorewardslist_table: dict[str, bool] = {}
+        self.honeybrewardslist_table: dict[str, bool] = {}
+        self.treblelist_table: dict[str, bool] = {}
+        self.stationlist_table: dict[str, bool] = {}
+        self.jinjofamlist_table: dict[str, bool] = {}
+        self.jinjolist_table: dict[str, bool] = {}
+        self.pages_table: dict[str, bool] = {}
+        self.honeycomb_table: dict[str, bool] = {}
+        self.glowbo_table: dict[str, bool] = {}
+        self.doubloon_table: dict[str, bool] = {}
+        self.notes_table: dict[str, bool] = {}
+        self.worldlist_table: dict[str, bool] = {}
+        self.chuffy_table: dict[str, bool] = {}
+        self.mystery_table: dict[str, bool] = {}
+        self.roystenlist_table: dict[str, bool] = {}
+        self.jiggychunks_table: dict[str, bool] = {}
         self.goggles_table = False
-        self.dino_kids_table = {}
-        self.boggy_kids_table = {}
-        self.alien_kids_table = {}
-        self.skivvies_table = {}
-        self.mr_fit_table = {}
-        self.bt_tickets_table = {}
-        self.green_relics_table = {}
-        self.beans_table = {}
+        self.dino_kids_table: dict[str, bool] = {}
+        self.boggy_kids_table: dict[str, bool] = {}
+        self.alien_kids_table: dict[str, bool] = {}
+        self.skivvies_table: dict[str, bool] = {}
+        self.mr_fit_table: dict[str, bool] = {}
+        self.bt_tickets_table: dict[str, bool] = {}
+        self.green_relics_table: dict[str, bool] = {}
+        self.beans_table: dict[str, bool] = {}
         self.signpost_table = {}
-        self.warppads_table = {}
-        self.silos_table = {}
-        self.nests_table = {}
+        self.warppads_table: dict[str, bool] = {}
+        self.silos_table: dict[str, bool] = {}
+        self.nests_table: dict[str, bool] = {}
         self.roar = False
-        self.jiggy_table = {}
+        self.jiggy_table: dict[str, bool] = {}
         self.current_map = 0
         self.deathlink_enabled = False
         self.deathlink_pending = False
@@ -347,12 +327,12 @@ class BanjoTooieContext(CommonContext):
         self.taglink_sent_this_tag = False
         self.taglink_client_override = False
         self.version_warning = False
-        self.messages = {}
+        self.messages: dict[int, dict[str, str | int] | str] = {}
         self.slot_data = {}
         self.sendSlot = False
         self.sync_ready = False
         self.startup = False
-        self.handled_scouts = []
+        self.handled_scouts: list[CreateHintsParams] = []
 
         if self.ready_callback:
             from kivy.clock import Clock
@@ -373,13 +353,10 @@ class BanjoTooieContext(CommonContext):
             return
         return
 
-    def _set_message(self, msg: dict, msg_id: Union[int, None]):
-        if msg_id == None:
-            self.messages.update({len(self.messages)+1: msg })
-        else:
-            self.messages.update({msg_id:msg})
+    def set_message(self, msg: dict[str, str | int] | str):
+        self.messages[len(self.messages)+1] = msg
 
-    def on_deathlink(self, data: dict):
+    def on_deathlink(self, data: dict[str, Any]):
         self.deathlink_pending = True
         self.last_death_link = max(data["time"], self.last_death_link)
         text = data.get("cause", "")
@@ -387,7 +364,7 @@ class BanjoTooieContext(CommonContext):
             logger.info(f"DeathLink: {text}")
 
     async def send_death(self, death_text: str = ""):
-        if self.server and self.server.socket:
+        if self.server and self.server.socket and self.slot is not None:
             logger.info(f"(DeathLink: Sending death to your friends...)")
             self.last_death_link = time.time()
             await self.send_msgs([{
@@ -446,24 +423,25 @@ class BanjoTooieContext(CommonContext):
         message = "Attempting to close this window again will forcibly close it."
         def cleanup(messagebox):
             self._messagebox = None
-        if self._messagebox and self._messagebox.title == title:
+        if self._messagebox and self._messagebox.title == title: # pyright: ignore[reportUnknownMemberType]
             return False
         if program and program.poll() == None:
             self.gui_error(title, message)
-            self._messagebox.bind(on_dismiss=cleanup)
+            if self._messagebox:
+              self._messagebox.bind(on_dismiss=cleanup) # pyright: ignore[reportCallIssue]
             return True
         return False
 
-    def on_package(self, cmd, args):
+    def on_package(self, cmd: str, args: dict[Any, Any]):
         if cmd == "Connected":
             self.tracker = BanjoTooieItemTracker(self)
-            self.slot_data = args.get("slot_data", None)
-            if version != self.slot_data["custom_bt_data"]["version"]:
-                logger.error("Your Banjo-Tooie AP does not match with the generated world.")
-                logger.error("Your version: "+version+" | Generated version: "+self.slot_data["custom_bt_data"]["version"])
-                # self.event_invalid_game()
-                raise Exception("Your Banjo-Tooie AP does not match with the generated world.\n" +
-                                "Your version: "+version+" | Generated version: "+self.slot_data["custom_bt_data"]["version"])
+            self.slot_data: dict[str, Any] = args.get("slot_data", {})
+            assert self.slot_data, "This slot doesn't have any data..."
+            slot_version = self.slot_data.get("custom_bt_data", {}).get("version", "N/A")
+            assert version == slot_version, (
+                "Your Banjo-Tooie AP does not match with the generated world.\n" +
+                f"Your version: {version} | Generated version: {self.slot_data['custom_bt_data']['version']}"
+            )
             self.deathlink_enabled = bool(self.slot_data["options"]["death_link"])
             self.taglink_enabled = bool(self.slot_data["options"]["tag_link"])
             self.n64_sync_task = asyncio.create_task(n64_sync_task(self), name="N64 Sync")
@@ -500,20 +478,19 @@ class BanjoTooieContext(CommonContext):
                 else:
                     self.pending_tag_link = True
 
-    def on_print_json(self, args: dict):
+    def on_print_json(self, args: dict[Any, Any]):
         if self.ui:
             self.ui.print_json(copy.deepcopy(args["data"]))
-            relevant = args.get("type", None) in {"ItemSend"}
+            relevant = args.get("type") == "ItemSend"
             if relevant:
                 relevant = False
                 item = args["item"]
-                if self.slot_concerns_self(args["receiving"]):
+                if self.slot_concerns_self(args["receiving"]): # pyright: ignore[reportUnknownMemberType]
                     relevant = True
-                elif self.slot_concerns_self(item.player):
+                elif self.slot_concerns_self(item.player): # pyright: ignore[reportUnknownMemberType]
                     relevant = True
 
                 if relevant == True:
-                    msg = self.raw_text_parser(copy.deepcopy(args["data"]))
                     player = self.player_names[int(args["data"][0]["text"])]
                     to_player = self.player_names[int(args["data"][0]["text"])]
                     for id, data in enumerate(args["data"]):
@@ -523,14 +500,12 @@ class BanjoTooieContext(CommonContext):
                             to_player = self.player_names[int(data["text"])]
                             break
                     item_name = self.item_names.lookup_in_slot(int(args["data"][2]["text"]))
-                    # self._set_message(msg, None)
-                    self._set_message({"player":player, "item":item_name, "item_id":int(args["data"][2]["text"]), "to_player":to_player }, None)
+                    self.set_message({"player":player, "item":item_name, "item_id":int(args["data"][2]["text"]), "to_player":to_player })
         else:
             text = self.jsontotextparser(copy.deepcopy(args["data"]))
             logger.info(text)
-            relevant = args.get("type", None) in {"ItemSend"}
+            relevant = args.get("type") == "ItemSend"
             if relevant:
-                msg = self.raw_text_parser(copy.deepcopy(args["data"]))
                 player = self.player_names[int(args["data"][0]["text"])]
                 to_player = self.player_names[int(args["data"][0]["text"])]
                 for id, data in enumerate(args["data"]):
@@ -540,8 +515,7 @@ class BanjoTooieContext(CommonContext):
                             to_player = self.player_names[int(data["text"])]
                             break
                 item_name = self.item_names.lookup_in_slot(int(args["data"][2]["text"]))
-                # self._set_message(msg, None)
-                self._set_message({"player":player, "item":item_name, "item_id":int(args["data"][2]["text"]), "to_player":to_player}, None)
+                self.set_message({"player":player, "item":item_name, "item_id":int(args["data"][2]["text"]), "to_player":to_player})
 
 def get_payload(ctx: BanjoTooieContext):
     if ctx.deathlink_enabled and ctx.deathlink_pending:
@@ -565,7 +539,7 @@ def get_payload(ctx: BanjoTooieContext):
     if ctx.sync_ready == True:
         ctx.startup = True
         payload = json.dumps({
-                "items": [get_item_value(item.item) for item in ctx.items_received],
+                "items": [item.item for item in ctx.items_received],
                 "playerNames": [name for (i, name) in ctx.player_names.items() if i != 0],
                 "triggerDeath": trigger_death,
                 "triggerTag": trigger_tag,
@@ -632,8 +606,49 @@ def get_slot_payload(ctx: BanjoTooieContext):
     ctx.sendSlot = False
     return payload
 
+class Payload(TypedDict):
+    playerName: str
+    deathlinkActive: bool
+    taglinkActive: bool
+    DEMO: Any
+    chuffy: dict[str, bool]
+    treble: dict[str, bool]
+    stations: dict[str, bool]
+    mystery: dict[str, bool]
+    roysten: dict[str, bool]
+    jinjofam: dict[str, bool]
+    jinjos: dict[str, bool]
+    pages: dict[str, bool]
+    honeycomb: dict[str, bool]
+    glowbo: dict[str, bool]
+    doubloon: dict[str, bool]
+    notes: dict[str, bool]
+    unlocked_moves: dict[str, bool]
+    hag: Any
+    cheato_rewards: dict[str, bool]
+    honeyb_rewards: dict[str, bool]
+    jiggy_chunks: dict[str, bool]
+    goggles: Any
+    jiggies: dict[str, bool]
+    dino_kids: dict[str, bool]
+    boggy_kids: dict[str, bool]
+    alien_kids: dict[str, bool]
+    skivvies: dict[str, bool]
+    fit_events: dict[str, bool]
+    nests: dict[str, bool]
+    roar: Any
+    signposts: dict[str, bool]
+    warppads: dict[str, bool]
+    silos: dict[str, bool]
+    worlds: dict[str, bool]
+    banjo_map: Any
+    bt_tickets: dict[str, bool]
+    green_relics: dict[str, bool]
+    beans: dict[str, bool]
+    isDead: bool
+    isTag: bool
 
-async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
+async def parse_payload(payload: Payload, ctx: BanjoTooieContext, force: bool):
 
     # Refuse to do anything if ROM is detected as changed
     if ctx.auth and payload["playerName"] != ctx.auth:
@@ -740,11 +755,11 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
         nests = {}
     if isinstance(signposts, list):
         signposts = {}
-    if isinstance(goggles, bool) == False:
+    if not isinstance(goggles, bool):
         goggles = False
-    if isinstance(demo, bool) == False:
+    if not isinstance(demo, bool):
         demo = True
-    if isinstance(banjo_map, int) == False:
+    if not isinstance(banjo_map, int):
         banjo_map = 0
     if isinstance(jiggylist, list):
         jiggylist = {}
@@ -766,9 +781,9 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
         warp_pads = {}
     if isinstance(silos, list):
         silos = {}
-    if isinstance(hag, bool) == False:
+    if not isinstance(hag, bool):
         hag = False
-    if isinstance(roar_obtain, bool) == False:
+    if not isinstance(roar_obtain, bool):
         roar_obtain = False
     if isinstance(bt_tickets, list):
         bt_tickets = {}
@@ -777,12 +792,8 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
     if isinstance(beans, list):
         beans = {}
 
-    @dataclass
-    class CreateHintsParams:
-        location: int
-        player: int
     if demo == False and ctx.sync_ready == True:
-        locs1 = []
+        locs1: list[int] = []
         create_hints_params: List[CreateHintsParams] = []
         if ctx.chuffy_table != chuffy:
             ctx.chuffy_table = chuffy
@@ -988,7 +999,7 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
                 "status": 30
             }])
             ctx.finished_game = True
-            ctx._set_message("You have completed your goal", None)
+            ctx.set_message("You have completed your goal")
 
         #Mumbo Tokens
         if (ctx.slot_data["options"]["victory_condition"] == 1 or ctx.slot_data["options"]["victory_condition"] == 2) and not ctx.finished_game:
@@ -1004,7 +1015,7 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
                             "status": 30
                         }])
                         ctx.finished_game = True
-                        ctx._set_message("You have completed your goal", None)
+                        ctx.set_message("You have completed your goal")
 
         if (ctx.current_map == 401 and ctx.slot_data["options"]["victory_condition"] == 5 and not ctx.finished_game):
             mumbo_tokens = 0
@@ -1068,7 +1079,7 @@ async def parse_payload(payload: dict, ctx: BanjoTooieContext, force: bool):
         else:
             ctx.taglink_sent_this_tag = False
 
-def mumbo_tokens_loc(locs: list, goaltype: int) -> list:
+def mumbo_tokens_loc(locs: list[int], goaltype: int) -> list[int]:
     for locationId in locs:
         if goaltype == 1 or goaltype == 4:
             if locationId == 1230598: #MT
@@ -1172,14 +1183,14 @@ async def n64_sync_task(ctx: BanjoTooieContext):
                         if not ctx.version_warning:
                             logger.warning(f"Your Lua script is version {reported_version}, expected {script_version}. "
                                 "Please update to the latest version. "
-                                "Your connection to the Archipelago server will not be accepted.")
+                                f"Your connection to the {apname} server will not be accepted.")
                             ctx.version_warning = True
                 except asyncio.TimeoutError:
                     logger.debug("Read Timed Out, Reconnecting")
                     error_status = CONNECTION_TIMING_OUT_STATUS
                     writer.close()
                     ctx.n64_streams = None
-                except ConnectionResetError as e:
+                except ConnectionResetError:
                     logger.debug("Read failed due to Connection Lost, Reconnecting")
                     error_status = CONNECTION_RESET_STATUS
                     writer.close()
