@@ -119,5 +119,5 @@ JRBOSS  = "Davy Jones' Locker"
 TLBOSS  = "Terry's Nest"
 GIBOSS  = "Repair Depot"
 HPFBOSS = "Chilli Billi Crater"
-HPIBOSS = "Chilli Willy Crater"
+HPIBOSS = "Chilly Willy Crater"
 CCBOSS  = "Mingy Jongo Skull"
