@@ -1,6 +1,5 @@
 from BaseClasses import ItemClassification
-from worlds.banjo_tooie.Names import locationName
-from ..Names import itemName
+from ..Names import itemName, locationName
 from ..Options import RandomizeCheatoRewards
 from .test_logic import EasyTricksLogic, GlitchesLogic, HardTricksLogic, IntendedLogic
 from . import BanjoTooieTestBase
