@@ -1,9 +1,12 @@
 from typing import Dict
 from ..Names import itemName
-from ..Options import EnableNestsanity, ProgressiveBashAttack, ProgressiveBeakBuster, ProgressiveEggAim, ProgressiveFlight, ProgressiveShoes, ProgressiveWaterTraining, RandomizeBKMoveList, RandomizeBTMoveList, RandomizeNotes, RandomizeStopnSwap
+from ..Options import EnableNestsanity, ProgressiveBashAttack, ProgressiveBeakBuster, \
+    ProgressiveEggAim, ProgressiveFlight, ProgressiveShoes, ProgressiveWaterTraining, \
+    RandomizeBKMoveList, RandomizeBTMoveList, RandomizeNotes, RandomizeStopnSwap
 from .test_logic import EasyTricksLogic, GlitchesLogic, HardTricksLogic, IntendedLogic
 from . import BanjoTooieTestBase
 
+
 class TestProgressiveMove(BanjoTooieTestBase):
     options = {
         "randomize_bt_moves": RandomizeBTMoveList.option_true,
@@ -18,6 +21,7 @@ class TestProgressiveMove(BanjoTooieTestBase):
         for item, expected_count in self.tested_items.items():
             assert item_pool_names.count(item) + starting_inventory_names.count(item) == expected_count
 
+
 class TestProgressiveBeakBuster(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -29,6 +33,7 @@ class TestProgressiveBeakBuster(TestProgressiveMove):
         itemName.BDRILL: 0
     }
 
+
 class TestNonProgressiveBeakBuster(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -40,6 +45,7 @@ class TestNonProgressiveBeakBuster(TestProgressiveMove):
         itemName.BDRILL: 1
     }
 
+
 class TestProgressiveShoes(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -54,6 +60,7 @@ class TestProgressiveShoes(TestProgressiveMove):
         itemName.CLAWBTS: 0,
     }
 
+
 class TestNonProgressiveShoes(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -67,6 +74,7 @@ class TestNonProgressiveShoes(TestProgressiveMove):
         itemName.CLAWBTS: 1,
     }
 
+
 class TestProgressiveAdvancedWaterTraining(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -82,6 +90,7 @@ class TestProgressiveAdvancedWaterTraining(TestProgressiveMove):
         itemName.AUQAIM: 0,
     }
 
+
 class TestProgressiveBasicWaterTraining(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -97,6 +106,7 @@ class TestProgressiveBasicWaterTraining(TestProgressiveMove):
         itemName.AUQAIM: 1,
     }
 
+
 class TestNonProgressiveWaterTraining(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -112,6 +122,7 @@ class TestNonProgressiveWaterTraining(TestProgressiveMove):
         itemName.AUQAIM: 1,
     }
 
+
 class TestProgressiveFlight(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -124,6 +135,7 @@ class TestProgressiveFlight(TestProgressiveMove):
         itemName.AIREAIM: 0,
     }
 
+
 class TestNonProgressiveFlight(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -136,6 +148,7 @@ class TestNonProgressiveFlight(TestProgressiveMove):
         itemName.AIREAIM: 1,
     }
 
+
 class TestProgressiveAdvancedEggAim(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -150,6 +163,7 @@ class TestProgressiveAdvancedEggAim(TestProgressiveMove):
         itemName.BBLASTER: 0,
     }
 
+
 class TestProgressiveBasicEggAim(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -164,6 +178,7 @@ class TestProgressiveBasicEggAim(TestProgressiveMove):
         itemName.BBLASTER: 1,
     }
 
+
 class TestNonProgressiveEggAim(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -178,6 +193,7 @@ class TestNonProgressiveEggAim(TestProgressiveMove):
         itemName.BBLASTER: 1,
     }
 
+
 class TestProgressiveBash(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -190,6 +206,7 @@ class TestProgressiveBash(TestProgressiveMove):
         itemName.BBASH: 0,
     }
 
+
 class TestNonProgressiveBash(TestProgressiveMove):
     options = {
         **TestProgressiveMove.options,
@@ -202,48 +219,56 @@ class TestNonProgressiveBash(TestProgressiveMove):
         itemName.BBASH: 1,
     }
 
+
 class TestTestProgressiveBeakBusterIntended(TestProgressiveBeakBuster, IntendedLogic):
     options = {
         **TestProgressiveBeakBuster.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestProgressiveBeakBusterEasyTricks(TestProgressiveBeakBuster, EasyTricksLogic):
     options = {
         **TestProgressiveBeakBuster.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestProgressiveBeakBusterHardTricks(TestProgressiveBeakBuster, HardTricksLogic):
     options = {
         **TestProgressiveBeakBuster.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestProgressiveBeakBusterGlitches(TestProgressiveBeakBuster, GlitchesLogic):
     options = {
         **TestProgressiveBeakBuster.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestNonProgressiveBeakBusterIntended(TestNonProgressiveBeakBuster, IntendedLogic):
     options = {
         **TestNonProgressiveBeakBuster.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestNonProgressiveBeakBusterEasyTricks(TestNonProgressiveBeakBuster, EasyTricksLogic):
     options = {
         **TestNonProgressiveBeakBuster.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveBeakBusterHardTricks(TestNonProgressiveBeakBuster, HardTricksLogic):
     options = {
         **TestNonProgressiveBeakBuster.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveBeakBusterGlitches(TestNonProgressiveBeakBuster, GlitchesLogic):
     options = {
         **TestNonProgressiveBeakBuster.options,
@@ -259,6 +284,7 @@ class TestTestProgressiveShoesIntended(TestProgressiveShoes, IntendedLogic):
 
     }
 
+
 class TestTestProgressiveShoesEasyTricks(TestProgressiveShoes, EasyTricksLogic):
     options = {
         **TestProgressiveShoes.options,
@@ -267,6 +293,7 @@ class TestTestProgressiveShoesEasyTricks(TestProgressiveShoes, EasyTricksLogic):
 
     }
 
+
 class TestTestProgressiveShoesHardTricks(TestProgressiveShoes, HardTricksLogic):
     options = {
         **TestProgressiveShoes.options,
@@ -275,6 +302,7 @@ class TestTestProgressiveShoesHardTricks(TestProgressiveShoes, HardTricksLogic):
 
     }
 
+
 class TestTestProgressiveShoesGlitches(TestProgressiveShoes, GlitchesLogic):
     options = {
         **TestProgressiveShoes.options,
@@ -283,264 +311,308 @@ class TestTestProgressiveShoesGlitches(TestProgressiveShoes, GlitchesLogic):
 
     }
 
+
 class TestTestNonProgressiveShoesIntended(TestNonProgressiveShoes, IntendedLogic):
     options = {
         **TestNonProgressiveShoes.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestNonProgressiveShoesEasyTricks(TestNonProgressiveShoes, EasyTricksLogic):
     options = {
         **TestNonProgressiveShoes.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveShoesHardTricks(TestNonProgressiveShoes, HardTricksLogic):
     options = {
         **TestNonProgressiveShoes.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveShoesGlitches(TestNonProgressiveShoes, GlitchesLogic):
     options = {
         **TestNonProgressiveShoes.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestProgressiveAdvancedWaterTrainingIntended(TestProgressiveAdvancedWaterTraining, IntendedLogic):
     options = {
         **TestProgressiveAdvancedWaterTraining.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestProgressiveAdvancedWaterTrainingEasyTricks(TestProgressiveAdvancedWaterTraining, EasyTricksLogic):
     options = {
         **TestProgressiveAdvancedWaterTraining.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestProgressiveAdvancedWaterTrainingHardTricks(TestProgressiveAdvancedWaterTraining, HardTricksLogic):
     options = {
         **TestProgressiveAdvancedWaterTraining.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestProgressiveAdvancedWaterTrainingGlitches(TestProgressiveAdvancedWaterTraining, GlitchesLogic):
     options = {
         **TestProgressiveAdvancedWaterTraining.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestProgressiveBasicWaterTrainingIntended(TestProgressiveBasicWaterTraining, IntendedLogic):
     options = {
         **TestProgressiveBasicWaterTraining.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestProgressiveBasicWaterTrainingEasyTricks(TestProgressiveBasicWaterTraining, EasyTricksLogic):
     options = {
         **TestProgressiveBasicWaterTraining.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestProgressiveBasicWaterTrainingHardTricks(TestProgressiveBasicWaterTraining, HardTricksLogic):
     options = {
         **TestProgressiveBasicWaterTraining.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestProgressiveBasicWaterTrainingGlitches(TestProgressiveBasicWaterTraining, GlitchesLogic):
     options = {
         **TestProgressiveBasicWaterTraining.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestNonProgressiveWaterTrainingIntended(TestNonProgressiveWaterTraining, IntendedLogic):
     options = {
         **TestNonProgressiveWaterTraining.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestNonProgressiveWaterTrainingEasyTricks(TestNonProgressiveWaterTraining, EasyTricksLogic):
     options = {
         **TestNonProgressiveWaterTraining.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveWaterTrainingHardTricks(TestNonProgressiveWaterTraining, HardTricksLogic):
     options = {
         **TestNonProgressiveWaterTraining.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveWaterTrainingGlitches(TestNonProgressiveWaterTraining, GlitchesLogic):
     options = {
         **TestNonProgressiveWaterTraining.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestProgressiveFlightIntended(TestProgressiveFlight, IntendedLogic):
     options = {
         **TestProgressiveFlight.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestProgressiveFlightEasyTricks(TestProgressiveFlight, EasyTricksLogic):
     options = {
         **TestProgressiveFlight.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestProgressiveFlightHardTricks(TestProgressiveFlight, HardTricksLogic):
     options = {
         **TestProgressiveFlight.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestProgressiveFlightGlitches(TestProgressiveFlight, GlitchesLogic):
     options = {
         **TestProgressiveFlight.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestNonProgressiveFlightIntended(TestNonProgressiveFlight, IntendedLogic):
     options = {
         **TestNonProgressiveFlight.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestNonProgressiveFlightEasyTricks(TestNonProgressiveFlight, EasyTricksLogic):
     options = {
         **TestNonProgressiveFlight.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveFlightHardTricks(TestNonProgressiveFlight, HardTricksLogic):
     options = {
         **TestNonProgressiveFlight.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveFlightGlitches(TestNonProgressiveFlight, GlitchesLogic):
     options = {
         **TestNonProgressiveFlight.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestProgressiveAdvancedEggAimIntended(TestProgressiveAdvancedEggAim, IntendedLogic):
     options = {
         **TestProgressiveAdvancedEggAim.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestProgressiveAdvancedEggAimEasyTricks(TestProgressiveAdvancedEggAim, EasyTricksLogic):
     options = {
         **TestProgressiveAdvancedEggAim.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestProgressiveAdvancedEggAimHardTricks(TestProgressiveAdvancedEggAim, HardTricksLogic):
     options = {
         **TestProgressiveAdvancedEggAim.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestProgressiveAdvancedEggAimGlitches(TestProgressiveAdvancedEggAim, GlitchesLogic):
     options = {
         **TestProgressiveAdvancedEggAim.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestProgressiveBasicEggAimIntended(TestProgressiveBasicEggAim, IntendedLogic):
     options = {
         **TestProgressiveBasicEggAim.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestProgressiveBasicEggAimEasyTricks(TestProgressiveBasicEggAim, EasyTricksLogic):
     options = {
         **TestProgressiveBasicEggAim.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestProgressiveBasicEggAimHardTricks(TestProgressiveBasicEggAim, HardTricksLogic):
     options = {
         **TestProgressiveBasicEggAim.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestProgressiveBasicEggAimGlitches(TestProgressiveBasicEggAim, GlitchesLogic):
     options = {
         **TestProgressiveBasicEggAim.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestNonProgressiveEggAimIntended(TestNonProgressiveEggAim, IntendedLogic):
     options = {
         **TestNonProgressiveEggAim.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestNonProgressiveEggAimEasyTricks(TestNonProgressiveEggAim, EasyTricksLogic):
     options = {
         **TestNonProgressiveEggAim.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveEggAimHardTricks(TestNonProgressiveEggAim, HardTricksLogic):
     options = {
         **TestNonProgressiveEggAim.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveEggAimGlitches(TestNonProgressiveEggAim, GlitchesLogic):
     options = {
         **TestNonProgressiveEggAim.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestProgressiveBashIntended(TestProgressiveBash, IntendedLogic):
     options = {
         **TestProgressiveBash.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestProgressiveBashEasyTricks(TestProgressiveBash, EasyTricksLogic):
     options = {
         **TestProgressiveBash.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestProgressiveBashHardTricks(TestProgressiveBash, HardTricksLogic):
     options = {
         **TestProgressiveBash.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestProgressiveBashGlitches(TestProgressiveBash, GlitchesLogic):
     options = {
         **TestProgressiveBash.options,
         **GlitchesLogic.options,
     }
 
+
 class TestTestNonProgressiveBashIntended(TestNonProgressiveBash, IntendedLogic):
     options = {
         **TestNonProgressiveBash.options,
         **IntendedLogic.options,
     }
 
+
 class TestTestNonProgressiveBashEasyTricks(TestNonProgressiveBash, EasyTricksLogic):
     options = {
         **TestNonProgressiveBash.options,
         **EasyTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveBashHardTricks(TestNonProgressiveBash, HardTricksLogic):
     options = {
         **TestNonProgressiveBash.options,
         **HardTricksLogic.options,
     }
 
+
 class TestTestNonProgressiveBashGlitches(TestNonProgressiveBash, GlitchesLogic):
     options = {
         **TestNonProgressiveBash.options,
