@@ -1,5 +1,4 @@
-from worlds.banjo_tooie.Names import locationName
-from ..Names import itemName
+from ..Names import itemName, locationName
 from ..Options import RandomizeChuffyTrain, RandomizeTrainStationSwitches
 from ..Items import stations_table
 from .test_logic import EasyTricksLogic, GlitchesLogic, HardTricksLogic, IntendedLogic
